﻿using Microsoft.Extensions.Logging;
using Plugin.BLE;
using Plugin.BLE.Abstractions.Contracts;

namespace RobobinApp;

public partial class App : Application
{
    public static IBluetoothLE BluetoothLE { get; private set; }
    public static IAdapter BluetoothAdapter { get; private set; }

    public App()
    {
        InitializeComponent();
        ConfigureLogging();

        // Initialize the Bluetooth adapter
        InitializeBluetoothAdapter();

        MainPage = new AppShell();
    }

    private void ConfigureLogging()
    {
        var loggerFactory = LoggerFactory.Create(builder =>
        {
            builder
                .AddConsole()
                .AddDebug();
        });

        Logger = loggerFactory.CreateLogger<App>();
    }

    private void InitializeBluetoothAdapter()
    {
        
        BluetoothLE = CrossBluetoothLE.Current;
        BluetoothAdapter = BluetoothLE.Adapter;
    }

    public ILogger<App> Logger { get; private set; }
}
